#!/bin/bash


# Parse JVM arguments in the configuration file
parse_ini()
{
	JAVA_ARGS=""
	#while read -r LINE
	for LINE in $(<"$1");
	do
		LINE=$(echo "$LINE" | sed -e $'s/\r//')	#LINE=$(echo "$LINE" | sed -e $'s/\x0D//')
		JAVA_ARGS="$JAVA_ARGS $LINE"
	#done < "$1"
	done
}

# Gets the real path of a link, following all links (readlink -f replacement working also on macOS)
myreadlink()
{
	[ ! -h "$1" ] && echo "$1" || (local link="$(expr "$(command ls -ld -- "$1")" : '.*-> \(.*\)$')"; cd $(dirname $1); myreadlink "$link" | sed "s|^\([^/].*\)\$|$(dirname $1)/\1|");
}


MYSELF="$(myreadlink $0)"
FNAME="$(basename $MYSELF)"
FNAME="${FNAME%.*}"
DIRNAME="$(dirname $MYSELF)"
JRE_DIR="$DIRNAME/jre"
JAR_FILE="$FNAME.jar"
CFG_FILE="$FNAME.l4j.ini"

JAVA_ARGS="-Xmx4096M -Dpython.console.encoding=UTF-8"
if [ -f ~/"$CFG_FILE" ]; then
    echo "Reading ~/$CFG_FILE"
	parse_ini ~/"$CFG_FILE"
else
	if [ -f "$DIRNAME"/"$CFG_FILE" ]; then
		echo "Reading $DIRNAME/$CFG_FILE"
		parse_ini "$DIRNAME"/"$CFG_FILE"
	fi
fi

if [[ "$OSTYPE" == "darwin"* ]]; then
	JAVA_ARGS="$JAVA_ARGS -Dapple.awt.application.name=$FNAME -Xdock:name=$FNAME -Xdock:icon=$DIRNAME/$FNAME.icns"
fi

if [ -d "$JRE_DIR" ]; then
	echo "Using bundled JRE"
	JAVA="$JRE_DIR/bin/java"
elif [ -n "$JAVA_HOME" ]; then
	echo "Using JRE from JAVA_HOME"
	JAVA="$JAVA_HOME/bin/java"
else
	echo "Using JRE from PATH"
	JAVA=java
fi

#echo "$MYSELF"
#echo "$FNAME"
#echo "$DIRNAME"
#echo "$JAR_FILE"
#echo "$JRE_DIR"
#echo "$JAVA"
#echo "$JAVA_ARGS"

exec $JAVA $JAVA_ARGS -jar "$DIRNAME"/"$JAR_FILE" "$@"
exit 1
