#!d:\Devel\Python\Python2.7.3\python.exe
# -*- coding: UTF-8 -*-

import os
import os.path as op
import sys
sys.path.insert(0, op.join(op.dirname(__file__), ".."))
from goatools.obo_parser import GODag, GraphEngines

def read_terms(fname):
    terms=[]
    f = open(fname, 'r')
    for line in f:
        terms.append(line.strip());
    f.close()
    
    return(terms)
    
if __name__ == '__main__':

    import optparse
    p = optparse.OptionParser("%prog [obo_file] [terms_file]")
    p.add_option("--description", dest="desc",
                 help="write term descriptions to stdout"
                 " from the obo file specified in args", action="store_true")
    p.add_option("--engine", default="pygraphviz",
                 choices=GraphEngines,
                 help="Graph plot engine, must be one of {0} [default: %default]".\
                        format("|".join(GraphEngines))
                 )
    p.add_option("--gml", action="store_true",
                 help="Write GML output (for Cytoscape) [default: %default]")
    p.add_option("--svg", action="store_true",
                 help="Write SVG output [default: %default]")                 
    p.add_option("--disable-draw-parents",
                 action="store_false",
                 dest='draw_parents',
                 help="Do not draw parents of the query term")
    p.add_option("--disable-draw-children",
                 action="store_false",
                 dest='draw_children',
                 help="Do not draw children of the query term")

    p.set_defaults(draw_parents=True)
    p.set_defaults(draw_children=True)

    opts, args = p.parse_args()
    print(opts)
    
    if len(args)==0:
        obo_file = "go-basic.obo"
        terms_file = "terms.txt"
    else:
        obo_file = args[0]    
        if len(args)==1:
            terms_file = "terms.txt"
        else:
            terms_file = args[1]
            
    assert os.path.exists(obo_file), "OBO file %s not found!" % obo_file
    assert os.path.exists(terms_file), "Terms file %s not found!" % terms_file

    g = GODag(obo_file)

    if opts.desc:
        g.write_dag()
    
    terms=read_terms(terms_file)
    recs=[]
    
    for term in terms:
        if not term==None and len(term)>0:
            rec = g.query_term(term, verbose=True)
            recs.append(rec);
    
    g.draw_lineage(recs, engine=opts.engine,gml=opts.gml,draw_parents=opts.draw_parents,draw_children=opts.draw_children,lineage_img="GO_lineage.png",svg=opts.svg)
